import importlib
import os
import sys


def context():
    class FakeContext:
        function_name = "FUNCTION_NAME"
        memory_limit_in_mb = 1024
        invoked_function_arn = "INVOKED_FUNCTION_ARN"
        aws_request_id = "AWS_REQUEST_ID"
        log_group_name = "LOG_GROUP_NAME"
        log_stream_name = "LOG_STREAM_NAME"

        def get_remaining_time_in_millis(self):
            # 5 minutes
            return 300000

    return FakeContext()


def load_lambda_module(request):
    # Inject environment variables
    backup_environ = {}
    for key, value in request.param.get("environ", {}).items():
        if key in os.environ:
            backup_environ[key] = os.environ[key]
        os.environ[key] = value

    # Add path for Lambda function
    sys.path.insert(
        0, os.path.dirname(os.path.abspath(request.param["module_name"]))
    )

    # Save the list of previously loaded modules
    prev_modules = list(sys.modules.keys())

    # Return the function module
    module = importlib.import_module(request.param["module_name"])
    yield module

    # Delete newly loaded modules
    new_keys = list(sys.modules.keys())
    for key in new_keys:
        if key not in prev_modules:
            del sys.modules[key]

    # Delete function module
    del module

    # Remove the Lambda function from path
    sys.path.pop(0)

    # Restore environment variables
    for key in request.param.get("environ", {}).keys():
        if key in backup_environ:
            os.environ[key] = backup_environ[key]
        else:
            del os.environ[key]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['druid_libs', 'druid_libs.tests_tools']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'druid-libs',
    'version': '0.1.15',
    'description': 'Python utilities for Druid projects',
    'long_description': '# Druid Libs \n![PythonSupport](https://img.shields.io/static/v1?label=python&message=3.7%20|%203.8|%203.9&color=blue?style=flat-square&logo=python) ![PyPI version](https://badge.fury.io/py/druid-libs.svg) ![PyPi monthly downloads](https://img.shields.io/pypi/dm/druid-libs)\n\nA suite of Python utilities to ease adopting best practices such as test mock lambda functions.\n\n## Features\n* **[MockLambda]()** - A utility that help you to test Lambda function handlers locally with unity test, this utility allow you invoke your lambda passing dinamically env variables to your function, to test his behavior.\n\n* **[FakeContext]()** - A utility that help you to test Lambda function handlers locally with unity test, using a fake context.\n\n* **[FakeEvent]()** - A utility that help you to create a fake event for API Gateway, this help you to work with verbs: GET, POST, DELETE, and UPDATE. \n\n### Installation\nWith [pip](https://pip.pypa.io/en/latest/index.html) installed, run: ``pip install druid-libs``\n\n## License\n\nThis library is licensed under the MIT-0 License. See the LICENSE file.',
    'author': 'Druid',
    'author_email': None,
    'maintainer': 'Geyson',
    'maintainer_email': 'geyson.ferreira@druid.com',
    'url': 'https://github.com/jasonFerre/python-lib',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from typing import Optional


class FakeEvent:
    def __init__(self) -> None:
        pass

    def proxy_api_event(self,
                        resource: str = "/",
                        path: str = "/",
                        method: str = "GET",
                        body: Optional[str] = None,
                        iam: Optional[str] = None,
                        cognito: Optional[str] = None,
                        path_params: Optional[dict] = None,
                        query_params: Optional[dict] = None,
                        ):
        return {
            "resource": resource,
            "path": path,
            "httpMethod": method,
            "headers": {
                "Accept": "*/*",
                "Accept-Encoding": "gzip, deflate, br",
                "CloudFront-Forwarded-Proto": "https",
                "CloudFront-Is-Desktop-Viewer": "true",
                "CloudFront-Is-Mobile-Viewer": "false",
                "CloudFront-Is-SmartTV-Viewer": "false",
                "CloudFront-Is-Tablet-Viewer": "false",
                "CloudFront-Viewer-Country": "BR",
                "Host": "qxdb8jvno4.execute-api.us-east-1.amazonaws.com",
                "Postman-Token": "e8531730-a73f-4c6a-ade2-e90a9151f78d",
                "User-Agent": "PostmanRuntime/7.26.8",
                "Via": "1.1 500f59fe7e67ec25b5c0692f11203995.cloudfront.net (CloudFront)",
                "X-Amz-Cf-Id": "nIeXAosYYVyqR_2-j1OfuAQW4W0Y8JjITxmXGe3XZ55AJwyy7fj8Vw==",
                "x-amz-date": "20210511T144925Z",
                "X-Amzn-Trace-Id": "Root=1-609a9974-39c9cddc0e4fe38d7334b081",
                "X-Forwarded-For": "201.95.56.60, 130.176.40.157",
                "X-Forwarded-Port": "443",
                "X-Forwarded-Proto": "https",
            },
            "multiValueHeaders": {
                "Accept": ["*/*"],
                "Accept-Encoding": ["gzip, deflate, br"],
                "CloudFront-Forwarded-Proto": ["https"],
                "CloudFront-Is-Desktop-Viewer": ["true"],
                "CloudFront-Is-Mobile-Viewer": ["false"],
                "CloudFront-Is-SmartTV-Viewer": ["false"],
                "CloudFront-Is-Tablet-Viewer": ["false"],
                "CloudFront-Viewer-Country": ["BR"],
                "Host": ["qxdb8jvno4.execute-api.us-east-1.amazonaws.com"],
                "Postman-Token": ["e8531730-a73f-4c6a-ade2-e90a9151f78d"],
                "User-Agent": ["PostmanRuntime/7.26.8"],
                "Via": [
                    "1.1 500f59fe7e67ec25b5c0692f11203995.cloudfront.net (CloudFront)"
                ],
                "X-Amz-Cf-Id": [
                    "nIeXAosYYVyqR_2-j1OfuAQW4W0Y8JjITxmXGe3XZ55AJwyy7fj8Vw=="
                ],
                "x-amz-date": ["20210511T144925Z"],
                "X-Amzn-Trace-Id": ["Root=1-609a9974-39c9cddc0e4fe38d7334b081"],
                "X-Forwarded-For": ["201.95.56.60, 130.176.40.157"],
                "X-Forwarded-Port": ["443"],
                "X-Forwarded-Proto": ["https"],
            },
            "queryStringParameters": query_params,
            "multiValueQueryStringParameters": None,
            "pathParameters": {"proxy": path_params},
            "stageVariables": None,
            "requestContext": {
                "resourceId": "bi0u94",
                "resourcePath": resource,
                "httpMethod": method,
                "extendedRequestId": "fKzqPEuOIAMFT0Q=",
                "requestTime": "11/May/2021:14:49:24 +0000",
                "path": path,
                "accountId": "653636420967",
                "protocol": "HTTP/1.1",
                "stage": "prod",
                "domainPrefix": "qxdb8jvno4",
                "requestTimeEpoch": 1620744564698,
                "requestId": "f50288c9-2111-4b6f-aca2-daef189c358d",
                "identity": {
                    "cognitoIdentityPoolId": cognito,
                    "accountId": "653636420967",
                    "cognitoIdentityId": cognito,
                    "caller": "AIDAZQL6EIVT7NTE4B6YP",
                    "sourceIp": "201.95.56.60",
                    "principalOrgId": "o-yuaj5cshgl",
                    "accessKey": "",
                    "cognitoAuthenticationType": None,
                    "cognitoAuthenticationProvider": None,
                    "userArn": None,
                    "userAgent": "PostmanRuntime/7.26.8",
                    "user": "AIDAZQL6EIVT7NTE4B6YP",
                },
                "domainName": "qxdb8jvno4.execute-api.us-east-1.amazonaws.com",
                "apiId": "qxdb8jvno4",
            },
            "body": body,
            "isBase64Encoded": False,
        }
